@@ -27,10 +27,14 @@ LOG = logging.getLogger(__name__)
 def _get_columns(item):
     column_map = {
         'is_enabled': 'enabled',
-        'tenant_id': 'project_id',
     }
 
-    return utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    hidden_columns = ['location', 'name', 'tenant_id']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 def _get_attrs(client_manager, parsed_args):
@@ -52,7 +56,7 @@ def _get_attrs(client_manager, parsed_args):
             parsed_args.project,
             parsed_args.project_domain,
         ).id
-        attrs['tenant_id'] = project_id
+        attrs['project_id'] = project_id
 
     return attrs
 
@@ -162,7 +166,7 @@ class ListNetworkFlavorProfile(command.Lister):
             'id',
             'driver',
             'is_enabled',
-            'metainfo',
+            'meta_info',
             'description',
         )
         column_headers = (
